# -*- coding: utf-8 -*-
import dateparser
import scrapy
import traceback
from scrapy.utils.project import get_project_settings
from ..helpers import CompanyMaker, Database
from ..items import ExaItem


db_settings = get_project_settings().get('DB')
db = Database(**db_settings)
comp = db.select("SELECT id, name, country FROM wp_esi_entity WHERE id = 3;")


class MobiHealthNewsSpider(scrapy.Spider):
    name = "mobihealthnews"
    allowed_domains = ["www.mobihealthnews.com"]

    def __init__(self):
        self.news = list()
        super(MobiHealthNewsSpider, self).__init__()

    def start_requests(self):
        companies = CompanyMaker(comp)
        companies.make_companies()
        for i in companies.get_companies():
            yield scrapy.Request(i.url, callback=self.parse, meta={'company': i,
                                                                   'post_id': 0})

    def parse(self, response):
        try:
            rows = response.xpath("..//div[contains(@class, 'group-left')]//div[contains(@class, 'views-row')]")
            company = response.meta['company']
            for i in rows:
                item = ExaItem()
                item['date'] = dateparser.parse(i.xpath(".//span/span[contains(@class, 'day_list')]/text()").extract_first()).date()
                item['title'] = i.xpath(".//span/a/text()").extract_first()
                item['description'] = i.xpath(".//div[contains(@class, 'views-field views-field-body')]/span/text()").extract_first()
                item['url'] = 'http://www.mobihealthnews.com' + i.xpath(".//span/a/@href").extract_first()

                item['region_id'] = company.region_id
                item['type_id'] = company.type_id
                item['media_id'] = company.media_id
                item['company_id'] = company.id

                item['post_id'] = response.meta['post_id']

                yield item
            has_next = response.xpath(
                "..//div[contains(@class, 'text-center')]/ul/li[contains(@class, 'next')]/a/text()").extract_first()
            next_url = 'http://www.mobihealthnews.com' + response.xpath(
                "..//div[contains(@class, 'text-center')]/ul/li[contains(@class, 'next')]/a/@href").extract_first()
            print(has_next, next_url)

            if has_next:
                # pass
                yield scrapy.Request(next_url, callback=self.parse, meta={'company': response.meta['company'], 'post_id': 0})

        except BaseException as e:
            print('We had error')
            traceback.print_exc()